import time
from urllib import parse, request
import ssl

def notify(token,msg):
    headers = {
        'User-Agent': 'Mozilla/5.0 (Windows NT 5.1) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/48.0.2564.82 Safari/537.36'}
    localtime = time.asctime( time.localtime(time.time()) )
    # print(localtime+'\n'+responses)
    data = parse.urlencode({'text': localtime+'\n'+msg}).encode()
    req = request.Request(
        "https://api.chanify.net/v1/sender/"+token.strip()+'?sound=1',
        data=data)
    context = ssl._create_unverified_context()
    request.urlopen(req,context=context)
    print("已通知，"+"本地时间为 :"+ localtime)


from setuptools import find_packages, setup

# Package meta-data.
import yue

NAME = 'yue'# and alpha0 0.0.0 from this
DESCRIPTION = 'A daily useful kit by KIN.'
URL = 'https://github.com/githubuser/kin.git'
EMAIL = 'emailuser@foxmail.com'
AUTHOR = 'KIN'
REQUIRES_PYTHON = '>=3.6.0'
VERSION = yue.VERSION

# What packages are required for this module to be executed?
REQUIRED = ['urllib3']

# Setting.
setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    author=AUTHOR,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(),
    install_requires=REQUIRED,
    license="MIT",
    platforms=["all"],
    long_description=open('README.md', 'r', encoding='utf-8').read(),
    long_description_content_type="text/markdown"
)